@@ -17,6 +17,11 @@ sub run
   my $servers = $blaster->memd->get("connected_servers") || [ ];
   @$servers = grep { $_ ne $blaster->config->hostname } @$servers;
   $blaster->memd->set("connected_servers", $servers);
+  
+  # Remove our active status indicator:
+  $blaster->memd->delete(
+    "Connected." . $blaster->config->hostname
+  );
 }# end run()
 
 1;# return true:
